--
-- Genesis
-- Specialization for a Genesis pack
--
-- @author  	PeterJ - FS-UK modteam
-- @version 	v1.0
-- @date  		20/11/2012
--

Genesis = {};

function Genesis.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations) and SpecializationUtil.hasSpecialization(Steerable, specializations);
end;

function Genesis:load(xmlFile)

	local rotationPart1Node = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.rotationParts.rotationPart1#index"));
		if rotationPart1Node ~= nil then
        self.rotationPart1 = {};
        self.rotationPart1.node = rotationPart1Node;

        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationParts.rotationPart1#minRot"));
        self.rotationPart1.minRot = {};
        self.rotationPart1.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationPart1.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationPart1.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationParts.rotationPart1#maxRot"));
        self.rotationPart1.maxRot = {};
        self.rotationPart1.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationPart1.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationPart1.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.rotationPart1.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationParts.rotationPart1#rotTime"), 2)*1000;
        self.rotationPart1.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationParts.rotationPart1#touchRotLimit"), 10));
    end;
	local rotationPart2Node = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.rotationParts.rotationPart2#index"));
    if rotationPart2Node ~= nil then
        self.rotationPart2 = {};
        self.rotationPart2.node = rotationPart2Node;

        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationParts.rotationPart2#minRot"));
        self.rotationPart2.minRot = {};
        self.rotationPart2.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationPart2.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationPart2.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationParts.rotationPart2#maxRot"));
        self.rotationPart2.maxRot = {};
        self.rotationPart2.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationPart2.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationPart2.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.rotationPart2.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationParts.rotationPart2#rotTime"), 2)*1000;
        self.rotationPart2.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationPart2#touchRotLimit"), 10));
    end;
	local rotationPart3Node = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.rotationParts.rotationPart3#index"));
    if rotationPart3Node ~= nil then
        self.rotationPart3 = {};
        self.rotationPart3.node = rotationPart3Node;

        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationParts.rotationPart3#minRot"));
        self.rotationPart3.minRot = {};
        self.rotationPart3.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationPart3.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationPart3.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationParts.rotationPart3#maxRot"));
        self.rotationPart3.maxRot = {};
        self.rotationPart3.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationPart3.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationPart3.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.rotationPart3.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationParts.rotationPart3#rotTime"), 2)*1000;
        self.rotationPart3.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationParts.rotationPart3#touchRotLimit"), 10));
    end;
	self.pedalsMovingUp = true;
	self.gasPedalMovingUp = false;
end;

function Genesis:delete()
end;

function Genesis:readStream(streamId, connection)
end;
  
function Genesis:writeStream(streamId, connection)
end;

function Genesis:mouseEvent(posX, posY, isDown, isUp, button)
end;

function Genesis:keyEvent(unicode, sym, modifier, isDown)
end;

function Genesis:update(dt)
	
	if self:getIsActive() then	

		inputAxisY = InputBinding.getAnalogInputAxis(InputBinding.AXIS_MOVE_FORWARD_VEHICLE);

        if InputBinding.isAxisZero(inputAxisY) then
        inputAxisY = InputBinding.getDigitalInputAxis(InputBinding.AXIS_MOVE_FORWARD_VEHICLE);
        end;
		if self.isEntered ~= nil then
			if self.movingDirection ~= 0 then
				if (self.movingDirection*self.lastSpeed*(-inputAxisY)) < -0.001 then		
					self.pedalsMovingUp = true;
					self.gasPedalMovingUp = false;
				else
					self.pedalsMovingUp = false;
					self.gasPedalMovingUp = true;
				end;
			else
				self.pedalsMovingUp = true;
				self.gasPedalMovingUp = false;
			end;
		end;

		if self.rotationPart1 ~= nil then
			local x, y, z = getRotation(self.rotationPart1.node);
			local rot = {x,y,z};
			local newRot = Utils.getMovedLimitedValues(rot, self.rotationPart1.maxRot, self.rotationPart1.minRot, 3, self.rotationPart1.rotTime, dt, not self.pedalsMovingUp);
			setRotation(self.rotationPart1.node, unpack(newRot));
		end;
		if self.rotationPart2 ~= nil then
			local x, y, z = getRotation(self.rotationPart2.node);
			local rot = {x,y,z};
			local newRot = Utils.getMovedLimitedValues(rot, self.rotationPart2.maxRot, self.rotationPart2.minRot, 3, self.rotationPart2.rotTime, dt, not self.pedalsMovingUp);
			setRotation(self.rotationPart2.node, unpack(newRot));
		end;
		if self.rotationPart3 ~= nil then
			local x, y, z = getRotation(self.rotationPart3.node);
			local rot = {x,y,z};
			local newRot = Utils.getMovedLimitedValues(rot, self.rotationPart3.maxRot, self.rotationPart3.minRot, 3, self.rotationPart3.rotTime, dt, not self.gasPedalMovingUp);
			setRotation(self.rotationPart3.node, unpack(newRot));
		end;
	end;
end;

function Genesis:updateTick(dt)
end;

function Genesis:draw()
end;

function Genesis:onEnter()
end;

function Genesis:onLeave()
end;
